==> ucx-1.3.0.tar.gz: ucx-1.3.0/src/tools/info/build_config.h <==
{"UCX_CONFIG_H", UCS_PP_MAKE_STRING()},
{"ENABLE_ASSERT", UCS_PP_MAKE_STRING(1)},
{"ENABLE_DEBUG_DATA", UCS_PP_MAKE_STRING(0)},
{"ENABLE_MT", UCS_PP_MAKE_STRING(0)},
{"ENABLE_PARAMS_CHECK", UCS_PP_MAKE_STRING(1)},
{"ENABLE_SYMBOL_OVERRIDE", UCS_PP_MAKE_STRING(1)},
{"HAVE_ATTRIBUTE_NOOPTIMIZE", UCS_PP_MAKE_STRING(1)},
{"HAVE_CMA", UCS_PP_MAKE_STRING(1)},
{"HAVE_CPLUS_DEMANGLE", UCS_PP_MAKE_STRING(1)},
{"HAVE_CUDA", UCS_PP_MAKE_STRING(0)},
{"HAVE_DECL_ASPRINTF", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_BASENAME", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_CPU_ISSET", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_CPU_ZERO", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_ETHTOOL_CMD_SPEED", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_FMEMOPEN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_F_SETOWN_EX", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EVENT_GID_CHANGE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_ACCESS_ALLOCATE_MR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_ACCESS_ON_DEMAND", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_ATOMIC_HCA_REPLY_BE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CQ_IGNORE_OVERRUN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CQ_MODERATION", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CREATE_QP", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CREATE_SRQ", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_DCT_OOO_RW_DATA_PLACEMENT", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_DEVICE_DC_TRANSPORT", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_DEVICE_MR_ALLOCATE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_MR_INDIRECT_KLMS", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_ODP_SUPPORT_IMPLICIT", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_POST_SEND", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_PREFETCH_MR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_PREFETCH_WRITE_ACCESS", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QPT_DC_INI", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QP_CREATE_UMR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QP_INIT_ATTR_ATOMICS_ARG", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QP_OOO_RW_DATA_PLACEMENT", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_REG_MR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_SEND_EXT_ATOMIC_INLINE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_SETENV", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_WR_EXT_MASKED_ATOMIC_CMP_AND_SWP", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_WR_EXT_MASKED_ATOMIC_FETCH_AND_ADD", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_WR_NOP", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_WR_UMR_FILL", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_LINK_LAYER_ETHERNET", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_LINK_LAYER_INFINIBAND", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_MLX5_EXP_GET_CQ_INFO", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_MLX5_EXP_GET_QP_INFO", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_MLX5_EXP_GET_SRQ_INFO", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_MLX5_EXP_UPDATE_CQ_CI", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_WC_STATUS_STR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_MLX5_WQE_CTRL_SOLICITED", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_SPEED_UNKNOWN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_STRDUPA", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL___PPC_GET_TIMEBASE_FREQ", UCS_PP_MAKE_STRING(0)},
{"HAVE_DETAILED_BACKTRACE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DLFCN_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_EXP_UMR", UCS_PP_MAKE_STRING(1)},
{"HAVE_EXP_UMR_NEW_API", UCS_PP_MAKE_STRING(1)},
{"HAVE_GDR_COPY", UCS_PP_MAKE_STRING(0)},
{"HAVE_HW_TIMER", UCS_PP_MAKE_STRING(1)},
{"HAVE_IB", UCS_PP_MAKE_STRING(1)},
{"HAVE_IBV_EXP_QP_CREATE_UMR", UCS_PP_MAKE_STRING(1)},
{"HAVE_IB_EXT_ATOMICS", UCS_PP_MAKE_STRING(1)},
{"HAVE_INFINIBAND_MLX5_HW_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_INTTYPES_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_KNEM", UCS_PP_MAKE_STRING(1)},
{"HAVE_LIBIBERTY_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_LIBRT", UCS_PP_MAKE_STRING(1)},
{"HAVE_MALLOC_GET_STATE", UCS_PP_MAKE_STRING(1)},
{"HAVE_MALLOC_HOOK", UCS_PP_MAKE_STRING(1)},
{"HAVE_MALLOC_SET_STATE", UCS_PP_MAKE_STRING(1)},
{"HAVE_MASKED_ATOMICS_ENDIANNESS", UCS_PP_MAKE_STRING(1)},
{"HAVE_MEMORY_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_MLX5_HW", UCS_PP_MAKE_STRING(1)},
{"HAVE_NUMA", UCS_PP_MAKE_STRING(1)},
{"HAVE_NUMAIF_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_NUMA_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_ROCM", UCS_PP_MAKE_STRING(0)},
{"HAVE_STDINT_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_STDLIB_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRINGS_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRING_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_BITMASK", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_DL_PHDR_INFO", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_ASYNC_EVENT_ELEMENT_DCT", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_CREATE_SRQ_ATTR_DC_OFFLOAD_PARAMS", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DCT_INIT_ATTR_INLINE_SIZE", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DEVICE_ATTR_EXP_DEVICE_CAP_FLAGS", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DEVICE_ATTR_ODP_CAPS", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DEVICE_ATTR_ODP_CAPS_PER_TRANSPORT_CAPS_DC_ODP_CAPS", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DEVICE_ATTR_ODP_MR_MAX_SIZE", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_QP_INIT_ATTR_MAX_INL_RECV", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_MLX5_QP_INFO_BF_NEED_LOCK", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_MLX5_GRH_AV_RMAC", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_MLX5_WQE_AV_BASE", UCS_PP_MAKE_STRING(1)},
{"HAVE_SYS_STAT_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_SYS_TYPES_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_SYS_UIO_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_TL_CM", UCS_PP_MAKE_STRING(1)},
{"HAVE_TL_DC", UCS_PP_MAKE_STRING(1)},
{"HAVE_TL_RC", UCS_PP_MAKE_STRING(1)},
{"HAVE_TL_UD", UCS_PP_MAKE_STRING(1)},
{"HAVE_UCM_PTMALLOC286", UCS_PP_MAKE_STRING(1)},
{"HAVE_UNISTD_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_VERBS_EXP_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_XPMEM", UCS_PP_MAKE_STRING(0)},
{"IBV_EXP_HW_TM", UCS_PP_MAKE_STRING(1)},
{"IBV_EXP_HW_TM_DC", UCS_PP_MAKE_STRING(1)},
{"LT_OBJDIR", UCS_PP_MAKE_STRING(".libs/")},
{"NVALGRIND", UCS_PP_MAKE_STRING(1)},
{"PACKAGE", UCS_PP_MAKE_STRING("ucx")},
{"PACKAGE_BUGREPORT", UCS_PP_MAKE_STRING("")},
{"PACKAGE_NAME", UCS_PP_MAKE_STRING("ucx")},
{"PACKAGE_STRING", UCS_PP_MAKE_STRING("ucx 1.3")},
{"PACKAGE_TARNAME", UCS_PP_MAKE_STRING("ucx")},
{"PACKAGE_URL", UCS_PP_MAKE_STRING("")},
{"PACKAGE_VERSION", UCS_PP_MAKE_STRING("1.3")},
{"STDC_HEADERS", UCS_PP_MAKE_STRING(1)},
{"UCS_MAX_LOG_LEVEL", UCS_PP_MAKE_STRING(UCS_LOG_LEVEL_TRACE_POLL)},
{"UCX_CONFIGURE_FLAGS", UCS_PP_MAKE_STRING("")},
{"VERSION", UCS_PP_MAKE_STRING("1.3")},
{"restrict", UCS_PP_MAKE_STRING(__restrict)},

==> ucx-1.4.0.tar.gz: ucx-1.4.0/src/tools/info/build_config.h <==
{"UCX_CONFIG_H", UCS_PP_MAKE_STRING()},
{"ENABLE_ASSERT", UCS_PP_MAKE_STRING(1)},
{"ENABLE_DEBUG_DATA", UCS_PP_MAKE_STRING(0)},
{"ENABLE_MT", UCS_PP_MAKE_STRING(0)},
{"ENABLE_PARAMS_CHECK", UCS_PP_MAKE_STRING(1)},
{"ENABLE_SYMBOL_OVERRIDE", UCS_PP_MAKE_STRING(1)},
{"HAVE_ATTRIBUTE_NOOPTIMIZE", UCS_PP_MAKE_STRING(1)},
{"HAVE_CMA", UCS_PP_MAKE_STRING(1)},
{"HAVE_CPLUS_DEMANGLE", UCS_PP_MAKE_STRING(1)},
{"HAVE_CUDA", UCS_PP_MAKE_STRING(0)},
{"HAVE_DECL_ASPRINTF", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_BASENAME", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_CPU_ISSET", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_CPU_ZERO", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_ETHTOOL_CMD_SPEED", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_FMEMOPEN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_F_SETOWN_EX", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_CMD_MODIFY_QP", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EVENT_GID_CHANGE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_ACCESS_ALLOCATE_MR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_ACCESS_ON_DEMAND", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_ATOMIC_HCA_REPLY_BE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CQ_IGNORE_OVERRUN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CQ_MODERATION", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CREATE_QP", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CREATE_RES_DOMAIN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_CREATE_SRQ", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_DCT_OOO_RW_DATA_PLACEMENT", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_DESTROY_RES_DOMAIN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_DEVICE_ATTR_RESERVED_2", UCS_PP_MAKE_STRING(0)},
{"HAVE_DECL_IBV_EXP_DEVICE_DC_TRANSPORT", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_DEVICE_MR_ALLOCATE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_MR_FIXED_BUFFER_SIZE", UCS_PP_MAKE_STRING(0)},
{"HAVE_DECL_IBV_EXP_MR_INDIRECT_KLMS", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_ODP_SUPPORT_IMPLICIT", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_POST_SEND", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_PREFETCH_MR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_PREFETCH_WRITE_ACCESS", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QPT_DC_INI", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QP_CREATE_UMR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QP_INIT_ATTR_ATOMICS_ARG", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QP_INIT_ATTR_RES_DOMAIN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_QP_OOO_RW_DATA_PLACEMENT", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_REG_MR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_RES_DOMAIN_THREAD_MODEL", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_SEND_EXT_ATOMIC_INLINE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_SETENV", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_WR_EXT_MASKED_ATOMIC_CMP_AND_SWP", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_WR_EXT_MASKED_ATOMIC_FETCH_AND_ADD", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_EXP_WR_NOP", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_LINK_LAYER_ETHERNET", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_LINK_LAYER_INFINIBAND", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_MLX5_EXP_GET_CQ_INFO", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_MLX5_EXP_GET_QP_INFO", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_MLX5_EXP_GET_SRQ_INFO", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_MLX5_EXP_UPDATE_CQ_CI", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_IBV_WC_STATUS_STR", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_MLX5_WQE_CTRL_SOLICITED", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_SPEED_UNKNOWN", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_STRDUPA", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL_STRERROR_R", UCS_PP_MAKE_STRING(1)},
{"HAVE_DECL___PPC_GET_TIMEBASE_FREQ", UCS_PP_MAKE_STRING(0)},
{"HAVE_DETAILED_BACKTRACE", UCS_PP_MAKE_STRING(1)},
{"HAVE_DLFCN_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_EXP_UMR", UCS_PP_MAKE_STRING(1)},
{"HAVE_GDR_COPY", UCS_PP_MAKE_STRING(0)},
{"HAVE_HW_TIMER", UCS_PP_MAKE_STRING(1)},
{"HAVE_IB", UCS_PP_MAKE_STRING(1)},
{"HAVE_IBV_EXP_DM", UCS_PP_MAKE_STRING(1)},
{"HAVE_IBV_EXP_QP_CREATE_UMR", UCS_PP_MAKE_STRING(1)},
{"HAVE_IBV_EXP_RES_DOMAIN", UCS_PP_MAKE_STRING(1)},
{"HAVE_IB_EXT_ATOMICS", UCS_PP_MAKE_STRING(1)},
{"HAVE_INFINIBAND_MLX5_HW_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_INTTYPES_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_KNEM", UCS_PP_MAKE_STRING(1)},
{"HAVE_LIBIBERTY_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_LIBRT", UCS_PP_MAKE_STRING(1)},
{"HAVE_MALLOC_GET_STATE", UCS_PP_MAKE_STRING(1)},
{"HAVE_MALLOC_HOOK", UCS_PP_MAKE_STRING(1)},
{"HAVE_MALLOC_SET_STATE", UCS_PP_MAKE_STRING(1)},
{"HAVE_MASKED_ATOMICS_ENDIANNESS", UCS_PP_MAKE_STRING(1)},
{"HAVE_MEMORY_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_MLX5_HW", UCS_PP_MAKE_STRING(1)},
{"HAVE_NUMA", UCS_PP_MAKE_STRING(1)},
{"HAVE_NUMAIF_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_NUMA_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_ROCM", UCS_PP_MAKE_STRING(0)},
{"HAVE_STDINT_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_STDLIB_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRERROR_R", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRINGS_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRING_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_BITMASK", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_DL_PHDR_INFO", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_ASYNC_EVENT_ELEMENT_DCT", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_CREATE_SRQ_ATTR_DC_OFFLOAD_PARAMS", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DCT_INIT_ATTR_INLINE_SIZE", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DEVICE_ATTR_EXP_DEVICE_CAP_FLAGS", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DEVICE_ATTR_ODP_CAPS", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DEVICE_ATTR_ODP_CAPS_PER_TRANSPORT_CAPS_DC_ODP_CAPS", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_DEVICE_ATTR_ODP_MR_MAX_SIZE", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_EXP_QP_INIT_ATTR_MAX_INL_RECV", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_IBV_MLX5_QP_INFO_BF_NEED_LOCK", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_MLX5_GRH_AV_RMAC", UCS_PP_MAKE_STRING(1)},
{"HAVE_STRUCT_MLX5_WQE_AV_BASE", UCS_PP_MAKE_STRING(1)},
{"HAVE_SYS_STAT_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_SYS_TYPES_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_SYS_UIO_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_TL_CM", UCS_PP_MAKE_STRING(1)},
{"HAVE_TL_DC", UCS_PP_MAKE_STRING(1)},
{"HAVE_TL_RC", UCS_PP_MAKE_STRING(1)},
{"HAVE_TL_UD", UCS_PP_MAKE_STRING(1)},
{"HAVE_UCM_PTMALLOC286", UCS_PP_MAKE_STRING(1)},
{"HAVE_UNISTD_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_VERBS_EXP_H", UCS_PP_MAKE_STRING(1)},
{"HAVE_XPMEM", UCS_PP_MAKE_STRING(0)},
{"IBV_EXP_HW_TM", UCS_PP_MAKE_STRING(1)},
{"IBV_EXP_HW_TM_DC", UCS_PP_MAKE_STRING(1)},
{"LT_OBJDIR", UCS_PP_MAKE_STRING(".libs/")},
{"NVALGRIND", UCS_PP_MAKE_STRING(1)},
{"PACKAGE", UCS_PP_MAKE_STRING("ucx")},
{"PACKAGE_BUGREPORT", UCS_PP_MAKE_STRING("")},
{"PACKAGE_NAME", UCS_PP_MAKE_STRING("ucx")},
{"PACKAGE_STRING", UCS_PP_MAKE_STRING("ucx 1.4")},
{"PACKAGE_TARNAME", UCS_PP_MAKE_STRING("ucx")},
{"PACKAGE_URL", UCS_PP_MAKE_STRING("")},
{"PACKAGE_VERSION", UCS_PP_MAKE_STRING("1.4")},
{"STDC_HEADERS", UCS_PP_MAKE_STRING(1)},
{"STRERROR_R_CHAR_P", UCS_PP_MAKE_STRING(1)},
{"UCS_MAX_LOG_LEVEL", UCS_PP_MAKE_STRING(UCS_LOG_LEVEL_TRACE_POLL)},
{"UCX_CONFIGURE_FLAGS", UCS_PP_MAKE_STRING("")},
{"VERSION", UCS_PP_MAKE_STRING("1.4")},
{"restrict", UCS_PP_MAKE_STRING(__restrict)},
